import type { IDataObject, INode, JsonObject } from './Interfaces';
type Severity = 'warning' | 'error';
interface ExecutionBaseErrorOptions {
    cause?: Error | JsonObject;
}
interface NodeOperationErrorOptions {
    message?: string;
    description?: string;
    runIndex?: number;
    itemIndex?: number;
    severity?: Severity;
    messageMapping?: {
        [key: string]: string;
    };
}
interface NodeApiErrorOptions extends NodeOperationErrorOptions {
    message?: string;
    httpCode?: string;
    parseXml?: boolean;
}
export declare abstract class ExecutionBaseError extends Error {
    description: string | null | undefined;
    cause: Error | JsonObject | undefined;
    timestamp: number;
    context: IDataObject;
    lineNumber: number | undefined;
    constructor(message: string, { cause }: ExecutionBaseErrorOptions);
    toJSON?(): any;
}
export declare abstract class NodeError extends ExecutionBaseError {
    node: INode;
    severity: Severity;
    constructor(node: INode, error: Error | JsonObject);
    protected findProperty(jsonError: JsonObject, potentialKeys: string[], traversalKeys?: string[]): string | null;
    protected setDescriptiveErrorMessage(message: string, description: string | undefined | null, code?: string | null, messageMapping?: {
        [key: string]: string;
    }): string[];
    protected updateDescription(message: string, description: string | undefined | null): string;
}
export declare class NodeOperationError extends NodeError {
    lineNumber: number | undefined;
    constructor(node: INode, error: Error | string, options?: NodeOperationErrorOptions);
}
export declare class NodeApiError extends NodeError {
    httpCode: string | null;
    constructor(node: INode, error: JsonObject, { message, description, httpCode, parseXml, runIndex, itemIndex, severity, messageMapping, }?: NodeApiErrorOptions);
    private setDescriptionFromXml;
    private setDefaultStatusCodeMessage;
}
export declare class NodeSSLError extends ExecutionBaseError {
    constructor(cause: Error);
}
export {};
